# speech_recognition

## Prerequisite
-   ```shell
    brew install portaudio
    pip install setuptools
    pip install pyaudio
    pip install google-cloud-speech
    ```
    


## Useful Links

- music: https://mixkit.co/free-sound-effects/desert/